@@ -22,7 +22,7 @@
  * - handling dcc send and dcc chat events;
  * - initiating dcc send and dcc chat.
  *
- * $Id: irctest.c 73 2009-01-03 11:14:59Z gyunaev $
+ * $Id: irctest.c 109 2012-01-24 03:06:42Z gyunaev $
  */
 
 #include <stdio.h>
@@ -51,7 +51,7 @@ void addlog (const char * fmt, ...)
 	va_list va_alist;
 
 	va_start (va_alist, fmt);
-#if defined (WIN32)
+#if defined (_WIN32)
 	_vsnprintf (buf, sizeof(buf), fmt, va_alist);
 #else
 	vsnprintf (buf, sizeof(buf), fmt, va_alist);
@@ -267,6 +267,7 @@ int main (int argc, char **argv)
 	irc_callbacks_t	callbacks;
 	irc_ctx_t ctx;
 	irc_session_t * s;
+	unsigned short port;
 
 	if ( argc != 4 )
 	{
@@ -310,13 +311,33 @@ int main (int argc, char **argv)
 
 	irc_set_ctx (s, &ctx);
 
-	if ( irc_connect (s, argv[1], 6667, 0, argv[2], 0, 0) )
+	// If the port number is specified in the server string, use the port 0 so it gets parsed
+	if ( strchr( argv[1], ':' ) != 0 )
+		port = 0;
+
+	// To handle the "SSL certificate verify failed" from command line we allow passing ## in front 
+	// of the server name, and in this case tell libircclient not to verify the cert
+	if ( argv[1][0] == '#' && argv[1][1] == '#' )
+	{
+		// Skip the first character as libircclient needs only one # for SSL support, i.e. #irc.freenode.net
+		argv[1]++;
+		
+		irc_option_set( s, LIBIRC_OPTION_SSL_NO_VERIFY );
+	}
+	
+	// Initiate the IRC server connection
+	if ( irc_connect (s, argv[1], port, 0, argv[2], 0, 0) )
 	{
 		printf ("Could not connect: %s\n", irc_strerror (irc_errno(s)));
 		return 1;
 	}
 
-	irc_run (s);
+	// and run into forever loop, generating events
+	if ( irc_run (s) )
+	{
+		printf ("Could not connect or I/O error: %s\n", irc_strerror (irc_errno(s)));
+		return 1;
+	}
 
 	return 1;
 }
